/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GuiFullLicenseFrameDescriptor.java 20819 2011-02-02 16:00:53Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.guifullstarter;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import org.ow2.jonas.autostart.configurationframe.ConfiguratorFrameDescriptor;
import org.ow2.jonas.autostart.frame.LicenseFrame;
import org.ow2.jonas.autostart.fullwizard.FullWizardPanelDescriptor;

/**
 * The License frame descriptor. It control the user action.
 * @author skabore
 */
public class GuiFullLicenseFrameDescriptor extends FullWizardPanelDescriptor implements ActionListener {

    /**
     * The identifier.
     */
    public static final String IDENTIFIER = "LICENSE_PANEL_FULL_STARTER";

    /**
     * The reconfiguration option.
     */
    private boolean reconf = false;

    /**
     * The license frame.
     */
    private LicenseFrame licenseFrame;

    /**
     * The default constructor.
     * @param reconf the reconfiguration option
     * @param steps, the required steps to create a starter
     */
    public GuiFullLicenseFrameDescriptor(final boolean reconf, final int steps) {
        this.reconf = reconf;
        licenseFrame = new LicenseFrame(steps);
        licenseFrame.addCheckBoxActionListener(this);
        setPanelDescriptorIdentifier(IDENTIFIER);
        setPanelComponent(licenseFrame);
    }

    /**
     * @return nextPanelDescriptor
     */
    @Override
    public Object getNextPanelDescriptor() {
        getWizard().getStopButton().setVisible(false);
        getWizard().getConfigButton().setVisible(false);
        if (reconf) {
            return ConfiguratorFrameDescriptor.IDENTIFIER;
        }
        return GuiFullRunningJonasOptionFrameDescriptor.IDENTIFIER;
    }

    /**
     * @return backPanelDescriptor
     */
    @Override
    public Object getBackPanelDescriptor() {
        getWizard().getStopButton().setVisible(false);
        getWizard().getConfigButton().setVisible(false);
        return GuiFullFirstFrameDescriptor.IDENTIFIER;
    }

    /**
     * Check if the panel can be displayed.
     */
    @Override
    public void aboutToDisplayPanel() {
        setNextButtonAccordingToCheckBox();
    }

    /**
     * Check if the radioa button 'I accept' is checked.
     */
    private void setNextButtonAccordingToCheckBox() {
        getWizard().setNextFinishButtonEnabled(licenseFrame.getAcceptLicenseRadioButton().isSelected());
    }

    /**
     * The action performed method.
     * @param event the action event.
     */
    public void actionPerformed(final ActionEvent event) {
        if (event.getSource() == licenseFrame.getAcceptLicenseRadioButton()) {
            getWizard().setNextFinishButtonEnabled(licenseFrame.getAcceptLicenseRadioButton().isSelected());
        } else {
            getWizard().setNextFinishButtonEnabled(!licenseFrame.getDoNotAcceptLicenseRadioButton().isSelected());
        }
    }
}
