/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GuiFullRunningJonasOptionFrameDescriptor.java 20819 2011-02-02 16:00:53Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.guifullstarter;

import java.awt.event.KeyEvent;

import org.ow2.jonas.autostart.configurationframe.ConfiguratorFrameDescriptor;
import org.ow2.jonas.autostart.frame.RunningJonasOptionFrame;
import org.ow2.jonas.autostart.fullwizard.FullWizardPanelDescriptor;
import org.ow2.jonas.autostart.starterfull.FullStarter;

/**
 * This class instantiates RunningJonasOptionFrame.
 * @author skabore
 */
public class GuiFullRunningJonasOptionFrameDescriptor extends FullWizardPanelDescriptor {

    /**
     * The starter librairy.
     */
    private FullStarter starter;

    /**
     * The identifier.
     */
    public static final String IDENTIFIER = "RUNNING_JONAS_OPTION_PANEL_FULL_STARTER";

    /**
     * The reconfiguration option.
     */
    private boolean reconf = false;

    /**
     * The RunningJonasOptionFrame.
     */
    private RunningJonasOptionFrame runningJonasOptionFrame;

    /**
     * The default constructor.
     * @param starter the starter librairy
     * @param reconf the reconfiguration option
     * @param steps, the required steps to create a starter
     * @param stepId, the sted number
     */
    public GuiFullRunningJonasOptionFrameDescriptor(final FullStarter starter, final boolean reconf, final int steps,
            final int stepId) {
        this.starter = starter;
        this.reconf = reconf;
        runningJonasOptionFrame = new RunningJonasOptionFrame(steps, stepId);
        setPanelDescriptorIdentifier(IDENTIFIER);
        setPanelComponent(runningJonasOptionFrame);
    }

    /**
     * @return starter.
     */
    public FullStarter getStarter() {
        return starter;
    }

    /**
     * @return the next panel.
     */
    @Override
    public Object getNextPanelDescriptor() {
        if (runningJonasOptionFrame.getEmbeddedJonasRadioButton().isSelected()) {
            return GuiFullRunningJonasFieldFromEmbeddedFrameDescriptor.IDENTIFIER;
        } else if (runningJonasOptionFrame.getExistingJonasDiskRadioButton().isSelected()) {
            return GuiFullRunningJonasFieldFromDiskFrameDescriptor.IDENTIFIER;
        }
        return null;
    }

    /**
     * @return the back panel.
     */
    @Override
    public Object getBackPanelDescriptor() {
        getWizard().getStopButton().setVisible(false);
        getWizard().getConfigButton().setVisible(false);
        if (reconf) {
            return ConfiguratorFrameDescriptor.IDENTIFIER;
        }
        return GuiFullLicenseFrameDescriptor.IDENTIFIER;
    }

    /**
     * Check if the next button must be enabled.
     */
    @Override
    public void aboutToDisplayPanel() {
    }

    /**
     * Set the next button text.
     */
    @Override
    public void displayingPanel() {
        getWizard().getNextButton().setText("Next");
        getWizard().getNextButton().setMnemonic(KeyEvent.VK_N);
    }
}
