/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GuiFullStarterFrame.java 20819 2011-02-02 16:00:53Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.guifullstarter;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.GridLayout;
import java.awt.Insets;
import java.awt.event.ActionListener;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JScrollPane;
import javax.swing.JSeparator;
import javax.swing.JTextArea;
import javax.swing.SpringLayout;
import javax.swing.border.EmptyBorder;

import org.ow2.jonas.autostart.starterfull.FullStarter;
import org.ow2.jonas.autostart.utility.SpringUtilities;

/**
 * This class creates main panel with starter fields.
 * @author skabore
 */
public class GuiFullStarterFrame extends JPanel {

    /**
     * The starter librairy.
     */
    private FullStarter starter;

    /**
     * The ouput textArea.
     */
    private JTextArea outputTextArea;

    /**
     * The blankSpace label.
     */
    private JLabel blankSpace;

    /**
     * The jPanel1 panel.
     */
    private JPanel jPanel1;

    /**
     * The progressDescription label.
     */
    private JLabel progressDescription;

    /**
     * The progressSent progressBar.
     */
    private JProgressBar progressSent;

    /**
     * The content panel.
     */
    private JPanel contentPanel;

    /**
     * The icon label.
     */
    private JLabel iconLabel;

    /**
     * The separator.
     */
    private JSeparator separator;

    /**
     * The text label.
     */
    private JLabel textLabel;

    /**
     * The title panel.
     */
    private JPanel titlePanel;

    /**
     * The showDetail button.
     */
    private JButton showDetailButton;

    /**
     * The scroll pane.
     */
    private JScrollPane scroll;

    /**
     * The constructor.
     * @param starter the starter librairy
     * @param steps, the required steps to create a starter
     */
    public GuiFullStarterFrame(final FullStarter starter, final int steps) {

        super();
        this.starter = starter;

        contentPanel = getContentPanel();
        ImageIcon icon = getImageIcon();

        titlePanel = new JPanel();
        textLabel = new JLabel();
        iconLabel = new JLabel();
        separator = new JSeparator();

        setLayout(new BorderLayout());

        titlePanel.setLayout(new BorderLayout());
        titlePanel.setBackground(Color.gray);

        textLabel.setBackground(Color.gray);
        textLabel.setFont(new Font("MS Sans Serif", Font.BOLD, 14));
        textLabel.setText("Running JOnAS server");
        textLabel.setBorder(new EmptyBorder(new Insets(10, 10, 10, 10)));
        textLabel.setOpaque(true);

        iconLabel.setBackground(Color.gray);
        if (icon != null) {
            iconLabel.setIcon(icon);
        }

        titlePanel.add(textLabel, BorderLayout.CENTER);
        titlePanel.add(new JLabel("7/" + steps + "   "), BorderLayout.EAST);
        titlePanel.add(separator, BorderLayout.SOUTH);

        add(titlePanel, BorderLayout.NORTH);
        JPanel secondaryPanel = new JPanel();
        secondaryPanel.add(contentPanel, BorderLayout.NORTH);
        add(secondaryPanel, BorderLayout.WEST);
    }

    /**
     * @return starter.
     */
    public FullStarter getStarter() {
        return starter;
    }

    /**
     * Set the starter.
     * @param starter the starter new value.
     */
    public void setStarter(final FullStarter starter) {
        this.starter = starter;
    }

    /**
     * Set the progressText value.
     * @param text the text.
     */
    public void setProgressText(final String text) {
        progressDescription.setText(text);
    }

    /**
     * Set the progressValue value.
     * @param value the value.
     */
    public void setProgressValue(final int value) {
        progressSent.setValue(value);
    }

    /**
     * @return outputTextArea.
     */
    public JTextArea getOutputTextArea() {
        return outputTextArea;
    }

    /**
     * @return progressDescription
     */
    public JLabel getProgressDescription() {
        return progressDescription;
    }

    /**
     * @return showDetailButton.
     */
    public JButton getShowDetailButton() {
        return showDetailButton;
    }

    /**
     * @return contentPanel1.
     */
    private JPanel getContentPanel() {

        JPanel contentPanel1 = new JPanel();

        jPanel1 = new JPanel();
        blankSpace = new JLabel();
        progressSent = new JProgressBar();
        progressDescription = new JLabel();
        outputTextArea = new JTextArea(35, 70);
        outputTextArea.setEditable(false);
        showDetailButton = new JButton("Hide details");

        contentPanel1.setLayout(new BorderLayout());

        jPanel1.setLayout(new GridLayout(0, 1));

        jPanel1.add(blankSpace);

        progressDescription.setFont(new Font("MS Sans Serif", 1, 11));
        jPanel1.add(progressDescription);
        progressSent.setStringPainted(false);
        progressSent.setPreferredSize(new Dimension(0, 20));
        jPanel1.add(progressSent);
        contentPanel1.add(jPanel1, BorderLayout.NORTH);

        JPanel detail = new JPanel(new SpringLayout());
        JPanel detailButtonPanel = new JPanel(new BorderLayout());
        detailButtonPanel.add(showDetailButton, BorderLayout.WEST);

        scroll = new JScrollPane(outputTextArea);
        detail.add(detailButtonPanel);
        scroll.setVisible(true);
        scroll.setPreferredSize(new Dimension(840, 450));
        detail.add(scroll);
        SpringUtilities.makeCompactGrid(detail, 2, 1, 0, 6, 0, 6);
        contentPanel1.add(detail, BorderLayout.CENTER);

        return contentPanel1;
    }

    /**
     * @return imageIcon. the image icon.
     */
    private ImageIcon getImageIcon() {
        return null;
    }

    /**
     * Show or hide the build detail process.
     */
    public void showDetail() {
        if (showDetailButton.getText().contains("Show")) {
            showDetailButton.setText("Hide details");
            scroll.setVisible(true);
        } else {
            showDetailButton.setText("Show details");
            scroll.setVisible(false);
        }
    }

    /**
     * Add actionListener to the buttons.
     * @param listener the listener.
     */
    public void addActionListener(final ActionListener listener) {
        showDetailButton.addActionListener(listener);
    }
}
